@@ -2,7 +2,7 @@
 #include <QtGui/QApplication>
 #include "qmlapplicationviewer.h"
 #include "windowhelper.h"
-//#include "filehandler.h"
+#include "filehandler.h"
 
 #ifdef HAVE_GLWIDGET
 
@@ -23,8 +23,10 @@ int main(int argc, char *argv[])
 
     WindowHelper *windowHelper = new WindowHelper();
     viewer.rootContext()->setContextProperty("windowHelper", windowHelper);
-//    FileHandler *fileHandler = new FileHandler();
-//    viewer.rootContext()->setContextProperty("fileHandler", fileHandler);
+    FileHandler *fileHandler = new FileHandler();
+    viewer.rootContext()->setContextProperty("fileHandler", fileHandler);
+    //PfoModel *pfoModel = new PfoModel();
+    //view.rootContext()->setContextProperty("pfoModel",  pfoModel());
 
     viewer.setAttribute(Qt::WA_NoSystemBackground);
     viewer.viewport()->setAttribute(Qt::WA_NoSystemBackground);
