@@ -296,25 +296,50 @@ function loadAllPortfolios() {
     loadPortfolio();
 }
 
-function loadOnePosition(posFeedLink) {
-    // Pull both return and transactions info
-//    itemsURL = posFeedLink+"?returns=true&transactions=true";
-    itemsURL = posFeedLink+"?returns=true";
-    //itemsURL = "http://finance.google.com/finance/feeds/default/portfolios/2/positions?returns=true";
-    console.log(itemsURL);
-    loadPosition();
+function loadOnePosition(posFeedLink, pfoLocal, pfoIsYahoo, loadPosFromFile) {
+    console.log("loadOnePosition: " + posFeedLink + " " + pfoLocal + " " + pfoIsYahoo + " " + loadPosFromFile);
+
+    if (pfoLocal) {
+        loadLocalPosition(posFeedLink, pfoIsYahoo, loadPosFromFile);
+    }
+    else {
+        // Pull both return and transactions info
+        // itemsURL = "http://finance.google.com/finance/feeds/default/portfolios/2/positions?returns=true";
+        // itemsURL = posFeedLink+"?returns=true&transactions=true";
+        itemsURL = posFeedLink+"?returns=true";
+        console.log(itemsURL);
+        loadPosition();
+    }
 }
 
 function loadOneQuote(symObj, idx) {
+
     itemsURL = "http://www.google.com/finance/info?client=ig&infotype=infoquoteall&q=" + symObj.symExg + ":" + symObj.symName;
     //console.log(itemsURL);
     loadQuote(symObj, idx);
 }
 
-function loadAllYahooQuote(quoteList) {
-    itemsURL =   "http://download.finance.yahoo.com/d/quotes.csv?s="+ quoteList + "&f=b2b3";
+function loadAllYahooQuote(quoteList, isYahooQuote) {
+    if (isYahooQuote) {
+        // b2, b3: ask, bid (real-time)
+        // g,h,j,k (day lo, day hi, 52w lo 52w hi)
+        // c6: change, k2: change percentage
+        // l1: last trade price
+        // j3: market cap
+        // a2: avg volume (3m), v: volume (real-time)
+        // r2: PE (real-time), r: PE
+        // e7: EPS Estimate Current Year
+        // x: stock exchange
+        // n: name
+        itemsURL =   "http://download.finance.yahoo.com/d/quotes.csv?s="+ quoteList + "&f=b2b3ghjkc6k2l1j3a2vr2e7xn";
+        loadYahooQuote();
+    }
+    else {
+        itemsURL =   "http://download.finance.yahoo.com/d/quotes.csv?s="+ quoteList + "&f=b2b3";
+        loadYahooQuote();
+    }
     //console.log(itemsURL);
-    loadYahooQuote();
+
 }
 
 function loadOnePortfolio(PortfolioName) {
@@ -325,7 +350,7 @@ function loadOnePortfolio(PortfolioName) {
 function loadPortfolio() {
     try {
         model.clear();
-        //pModel.clear();
+        // pModel.clear();
         // Have to set to "portfolio", o.w. stategroup error message
         waiting.state = "shown";
         doWebRequest("GET", itemsURL, 0, parsePortfolio, 1);
@@ -390,7 +415,6 @@ function loadQuote(symObj, idx) {
 
                      "quoteAsk":       "-",
                      "quoteBid":       "-"
-
         });
     }
     else {
@@ -461,10 +485,7 @@ function parsePortfolio(data) {
             // Push to pfoModel
             if (i<model.count) {
                 model.set(i, {
-                             //"idx": i,
-                             //"etag": pfoEtag,
                              "name": pfoName,
-                             //"id": pfoId,
                              "feedLink": pfoFeedLink,
                              //"currency": currency,
                              //"gainPercent": pfoGainPercent,
@@ -475,15 +496,13 @@ function parsePortfolio(data) {
             }
             else {
                 model.append({
-                             //"idx": i,
-                             //"etag": pfoEtag,
                              "local": 0,
                              "name": pfoName,
-                             //"id": pfoId,
                              "feedLink": pfoFeedLink,
                              //"currency": currency,
                              //"gainPercent": pfoGainPercent,
                              //"rtnYTD": pfoRtnYTD,
+                             "isYahoo": false,
                              "excerpt": "-",
                              "num": 0
                 });
@@ -510,20 +529,7 @@ function parsePortfolio(data) {
     //    addError("Error: " + err);
     //}
         // Load local portfolio
-
-//        var fileOk = fileHandler.loadPfo();
-
-//        if (fileOk==0){
-//            for (var i=0; i < fileHandler.localPfoName.length; i++) {
-//                model.append({
-//                             "local": 1,
-//                             "name": fileHandler.localPfoName[i],
-//                             "feedLink": "",
-//                             "excerpt": fileHandler.localPfoDesc[i],
-//                             "num": fileHandler.localPfoNum[i]
-//                });
-//            }
-//        }
+        loadLocalPortfolio();
 
     waiting.state = "hidden";
 }
@@ -550,6 +556,62 @@ function parsePortfolioNum(data, pfoIdx) {
     }
 }
 
+// Local
+function loadLocalPortfolio() {
+
+    var fileOk = fileHandler.loadPfo();
+
+    if (fileOk==0){
+        for (var i=0; i < fileHandler.localPfoName.length; i++) {
+            model.append({
+                         "local": 1,
+                         "name": fileHandler.localPfoName[i],
+                         "feedLink": "",
+                         "excerpt": fileHandler.localPfoDesc[i],
+                         "isYahoo": fileHandler.localPfoIsYahoo[i],
+                         "num": fileHandler.localPfoNum[i]
+            });
+        }
+    }
+}
+
+function loadLocalPosition(pfoIdx, pfoIsYahoo, loadPosFromFile) {
+
+    if (loadPosFromFile) {
+        fileHandler.loadPos(pfoIdx);
+    }
+
+    var quoteList = "";
+
+    for (var i=0; i<fileHandler.localPosSymbol.length; i++) {
+        console.log(i + ":" + fileHandler.localPosSymbol[i]);
+
+        var symObj = {
+            "symName": fileHandler.localPosSymbol[i],
+            "symExg": fileHandler.localPosExg[i],
+            "symShare": fileHandler.localPosShare[i],
+            "shareCost": fileHandler.localPosCost[i],
+            "shareDayGain": 0,
+            "shareGain": 0,
+            "shareValue": 0,
+            "shareGainPercent": 0
+        };
+
+        if (!pfoIsYahoo) {
+            loadOneQuote(symObj, i);
+        }
+        quoteList = quoteList + "+" + convertExchangeForYahoo(symObj.symName, symObj.symExg);
+    }
+
+    //waiting.reason = quoteList + "-" + fileHandler.localPosSymbol.length;
+
+    // Take out leading +
+    quoteList = quoteList.replace(/^\+/, "");
+    loadAllYahooQuote(quoteList, pfoIsYahoo);
+
+    waiting.state = "hidden";
+}
+
 function parsePosition(data) {
     //try {
         // 2) XML DOM
@@ -696,7 +758,7 @@ function parsePosition(data) {
 
         // Take out leading +
         quoteList = quoteList.replace(/^\+/, "");
-        loadAllYahooQuote(quoteList);
+        loadAllYahooQuote(quoteList, 0);
 
     //}catch(err) {
     //    addError("Error: " + err);
@@ -706,15 +768,6 @@ function parsePosition(data) {
 
 // There is a Yahoo real-time feed!
 function parseCSV(data) {
-    /*
-      Ask: b2
-      Bid: b3
-      Ask size: a5
-      Bid size: b6
-      After Hours Change (Real-time): c8 (broken?)
-      d: dividend per share (inconsistent with GF)
-      y: dividend yield (inconsistent with GF)
-    */
     // Array[Row][Column]
     //console.log(data);
     var csvObj = CSVToArray(data);
@@ -724,12 +777,109 @@ function parseCSV(data) {
         return;
     }
     else {
-        for (var i=0; i<pModel.count; i=i+1) {
-            //console.log(i+":(Ask,Bid) = "+csvObj[i][0] + "/" + csvObj[i][1])
-            pModel.set(i, {
-                       "quoteAsk": (csvObj[i][0]=="N/A") ? "-" : csvObj[i][0],
-                       "quoteBid": (csvObj[i][1]=="N/A") ? "-" : csvObj[i][1]
-        });
+        // b2, b3: ask, bid (real-time)
+        if (csvObj[0].length==2) {
+            for (var i=0; i<pModel.count; i=i+1) {
+                //console.log(i+":(Ask,Bid) = "+csvObj[i][0] + "/" + csvObj[i][1])
+                pModel.set(i, {
+                           "quoteAsk": (csvObj[i][0]=="N/A") ? "-" : csvObj[i][0],
+                           "quoteBid": (csvObj[i][1]=="N/A") ? "-" : csvObj[i][1]
+                });
+            }
+        }
+        // b2, b3: ask, bid (real-time)
+        // g,h,j,k (day lo, day hi, 52w lo 52w hi)
+        // c6: change, k2: change percentage
+        // l1: last trade price
+        // j3: market cap
+        // a2: avg volume (3m), v: volume (real-time)
+        // r2: PE (real-time), r: PE
+        // e7: EPS Estimate Current Year
+        // x: stock exchange
+        // n: name
+        else {
+             for (var i=0; i<fileHandler.localPosSymbol.length; i=i+1) {
+                 var change = csvObj[i][7];
+
+                 var quoteChgColor;
+                 if (change.match(/\+/)=="+") {
+                     quoteChgColor = "green";
+                     //shareCost = formatNumber(shareValue/(1+parseFloat(gainPtg)));
+                 }
+                 else {
+                     quoteChgColor = "red";
+                     //shareCost = formatNumber(shareValue/(1-parseFloat(gainPtg)));
+                 }
+
+                 // Split string
+                 change = change.split(" - ");
+                 change[1] = change[1].substr(0, change[1].indexOf("%"));
+
+                 if (pModel.count==0) {
+                        pModel.append({
+                             "exchange":   (csvObj[i][14]=="N/A") ? "-" : csvObj[i][14],
+                             "fullName":   (csvObj[i][15]=="N/A") ? "-" : csvObj[i][15],
+                             "name":         fileHandler.localPosSymbol[i],
+                             "share":        fileHandler.localPosShare[i],
+                             "shareGain":    0,
+                             "shareCost":    fileHandler.localPosCost[i],
+                             "shareDayGain": 0,
+                             "shareValue":   0,
+                             "shareGainPercent": 0,
+
+                             "quoteAsk":   (csvObj[i][0]=="N/A") ? "-" : csvObj[i][0],
+                             "quoteBid":   (csvObj[i][1]=="N/A") ? "-" : csvObj[i][1],
+                             "quotePrice": (csvObj[i][8]=="N/A") ? "-" : csvObj[i][8],
+                             "quoteChgColor": quoteChgColor,
+
+                             "quoteChg":   (change[0]=="N/A") ? "-" : change[0],
+                             "quoteChgPtg":(change[1]=="N/A") ? "-" : change[1],
+                             "quoteVol":   (csvObj[i][11]=="N/A") ? "-" : csvObj[i][11],
+                             "quoteAvgVol":(csvObj[i][10]=="N/A") ? "-" : csvObj[i][10],
+                             "quoteMktCap":(csvObj[i][9]=="N/A") ? "-" : csvObj[i][9],
+                             "quoteDayHi": (csvObj[i][3]=="N/A") ? "-" : csvObj[i][3],
+                             "quoteDayLo": (csvObj[i][2]=="N/A") ? "-" : csvObj[i][2],
+                             "quote52wHi": (csvObj[i][5]=="N/A") ? "-" : csvObj[i][5],
+                             "quote52wLo": (csvObj[i][4]=="N/A") ? "-" : csvObj[i][4],
+                             "quoteEps":   (csvObj[i][13]=="N/A") ? "-" : csvObj[i][13],
+                             "quoteBeta":   "-",
+                             "quotePe":    (csvObj[i][12]=="N/A") ? "-" : csvObj[i][12],
+                             "quoteType":   "-"
+                        });
+                 }
+                 else {
+                     pModel.set(i, {
+                                "exchange":   (csvObj[i][14]=="N/A") ? "-" : csvObj[i][14],
+                                "fullName":   (csvObj[i][15]=="N/A") ? "-" : csvObj[i][15],
+                                "name":         fileHandler.localPosSymbol[i],
+                                "share":        fileHandler.localPosShare[i],
+                                "shareGain":    0,
+                                "shareCost":    fileHandler.localPosCost[i],
+                                "shareDayGain": 0,
+                                "shareValue":   0,
+                                "shareGainPercent": 0,
+
+                                "quoteAsk":   (csvObj[i][0]=="N/A") ? "-" : csvObj[i][0],
+                                "quoteBid":   (csvObj[i][1]=="N/A") ? "-" : csvObj[i][1],
+                                "quotePrice": (csvObj[i][8]=="N/A") ? "-" : csvObj[i][8],
+                                "quoteChgColor": quoteChgColor,
+
+                                "quoteChg":   (change[0]=="N/A") ? "-" : change[0],
+                                "quoteChgPtg":(change[1]=="N/A") ? "-" : change[1],
+                                "quoteVol":   (csvObj[i][11]=="N/A") ? "-" : csvObj[i][11],
+                                "quoteAvgVol":(csvObj[i][10]=="N/A") ? "-" : csvObj[i][10],
+                                "quoteMktCap":(csvObj[i][9]=="N/A") ? "-" : csvObj[i][9],
+                                "quoteDayHi": (csvObj[i][3]=="N/A") ? "-" : csvObj[i][3],
+                                "quoteDayLo": (csvObj[i][2]=="N/A") ? "-" : csvObj[i][2],
+                                "quote52wHi": (csvObj[i][5]=="N/A") ? "-" : csvObj[i][5],
+                                "quote52wLo": (csvObj[i][4]=="N/A") ? "-" : csvObj[i][4],
+                                "quoteEps":   (csvObj[i][13]=="N/A") ? "-" : csvObj[i][13],
+                                "quoteBeta":   "-",
+                                "quotePe":    (csvObj[i][12]=="N/A") ? "-" : csvObj[i][12],
+                                "quoteType":   "-"
+                     });
+                 }
+             }
         }
     }
 }
@@ -838,7 +988,7 @@ function convertExchangeForYahoo (name, exg) {
     else if (exg=="SHA")              { return (name + "." + "SS"); }
     else if (exg=="SHE")              { return (name + "." + "SZ"); }
     else if (exg=="SEO")              { return (name + "." + "KS"); }
-    else                              { return "NULL"; }
+    else                              { return name; }
 }
 
 function removeComment(data) {
